==> localstack-ext-0.13.0.10.tar.gz: localstack-ext-0.13.0.10/localstack_ext/bootstrap/cpvcs/utils/hash_utils.py <==
import hashlib
Ftyek=str
FtyeA=hex
FtyeH=None
Ftyeo=open
FtyeS=Exception
FtyeW=int
Ftyeb=map
Ftyea=isinstance
import logging
import os
import random
import zipfile
from typing import Optional
from localstack.utils.common import new_tmp_dir,rm_rf
from localstack_ext.bootstrap.cpvcs.models import CPVCSNode,Revision,Version
from localstack_ext.bootstrap.cpvcs.utils.common import config_context
from localstack_ext.bootstrap.state_utils import API_STATES_DIR,api_states_traverse
LOG=logging.getLogger(__name__)
def random_hash()->Ftyek:
 return FtyeA(random.getrandbits(160))
def compute_file_hash(file_path:Ftyek,accum=FtyeH)->Optional[Ftyek]:
 try:
  with Ftyeo(file_path,"rb")as fp:
   if accum:
    accum.update(fp.read())
   else:
    return hashlib.sha1(fp.read()).hexdigest()
 except FtyeS as e:
  LOG.warning(f"Failed to open file and compute hash for file at {file_path}: {e}")
def compute_version_archive_hash(version_no:FtyeW,state_archive:Ftyek)->Ftyek:
 def _compute_file_hash_func(**kwargs):
  dir_name=kwargs.get("dir_name")
  file_name=kwargs.get("fname")
  accum=kwargs.get("mutables")[0]
  file_path=os.path.join(dir_name,file_name)
  compute_file_hash(file_path,accum)
 tmp_state_dir=new_tmp_dir()
 with zipfile.ZipFile(state_archive)as archive:
  archive.extractall(tmp_state_dir)
 tmp_state_archive_api_states=os.path.join(tmp_state_dir,API_STATES_DIR)
 m=hashlib.sha1()
 api_states_traverse(tmp_state_archive_api_states,_compute_file_hash_func,[m])
 m.update(Ftyek(version_no).encode("utf-8"))
 rm_rf(tmp_state_dir)
 return m.hexdigest()
def compute_node_hash(cpvcs_node:CPVCSNode)->Ftyek:
 if not cpvcs_node.state_files:
  return random_hash()
 state_file_keys=Ftyeb(lambda state_file:state_file.hash_ref,cpvcs_node.state_files)
 m=hashlib.sha1()
 for key in state_file_keys:
  try:
   with Ftyeo(os.path.join(config_context.get_obj_store_path(),key),"rb")as fp:
    m.update(fp.read())
  except FtyeS as e:
   LOG.warning(f"Failed to open file and compute hash for {key}: {e}")
 if Ftyea(cpvcs_node,Revision):
  m.update(cpvcs_node.rid.encode("utf-8"))
  m.update(Ftyek(cpvcs_node.revision_number).encode("utf-8"))
 elif Ftyea(cpvcs_node,Version):
  m.update(Ftyek(cpvcs_node.version_number).encode("utf-8"))
 return m.hexdigest()
# Created by pyminifier (https://github.com/liftoff/pyminifier)

==> localstack-ext-0.13.0.11.tar.gz: localstack-ext-0.13.0.11/localstack_ext/bootstrap/cpvcs/utils/hash_utils.py <==
import hashlib
RTHSY=str
RTHSI=hex
RTHSw=None
RTHSg=open
RTHSy=Exception
RTHSv=int
RTHSx=map
RTHSV=isinstance
import logging
import os
import random
import zipfile
from typing import Optional
from localstack.utils.common import new_tmp_dir,rm_rf
from localstack_ext.bootstrap.cpvcs.models import CPVCSNode,Revision,Version
from localstack_ext.bootstrap.cpvcs.utils.common import config_context
from localstack_ext.bootstrap.state_utils import API_STATES_DIR,api_states_traverse
LOG=logging.getLogger(__name__)
def random_hash()->RTHSY:
 return RTHSI(random.getrandbits(160))
def compute_file_hash(file_path:RTHSY,accum=RTHSw)->Optional[RTHSY]:
 try:
  with RTHSg(file_path,"rb")as fp:
   if accum:
    accum.update(fp.read())
   else:
    return hashlib.sha1(fp.read()).hexdigest()
 except RTHSy as e:
  LOG.warning(f"Failed to open file and compute hash for file at {file_path}: {e}")
def compute_version_archive_hash(version_no:RTHSv,state_archive:RTHSY)->RTHSY:
 def _compute_file_hash_func(**kwargs):
  dir_name=kwargs.get("dir_name")
  file_name=kwargs.get("fname")
  accum=kwargs.get("mutables")[0]
  file_path=os.path.join(dir_name,file_name)
  compute_file_hash(file_path,accum)
 tmp_state_dir=new_tmp_dir()
 with zipfile.ZipFile(state_archive)as archive:
  archive.extractall(tmp_state_dir)
 tmp_state_archive_api_states=os.path.join(tmp_state_dir,API_STATES_DIR)
 m=hashlib.sha1()
 api_states_traverse(tmp_state_archive_api_states,_compute_file_hash_func,[m])
 m.update(RTHSY(version_no).encode("utf-8"))
 rm_rf(tmp_state_dir)
 return m.hexdigest()
def compute_node_hash(cpvcs_node:CPVCSNode)->RTHSY:
 if not cpvcs_node.state_files:
  return random_hash()
 state_file_keys=RTHSx(lambda state_file:state_file.hash_ref,cpvcs_node.state_files)
 m=hashlib.sha1()
 for key in state_file_keys:
  try:
   with RTHSg(os.path.join(config_context.get_obj_store_path(),key),"rb")as fp:
    m.update(fp.read())
  except RTHSy as e:
   LOG.warning(f"Failed to open file and compute hash for {key}: {e}")
 if RTHSV(cpvcs_node,Revision):
  m.update(cpvcs_node.rid.encode("utf-8"))
  m.update(RTHSY(cpvcs_node.revision_number).encode("utf-8"))
 elif RTHSV(cpvcs_node,Version):
  m.update(RTHSY(cpvcs_node.version_number).encode("utf-8"))
 return m.hexdigest()
# Created by pyminifier (https://github.com/liftoff/pyminifier)
